### Overview
ThreeDViewer is a plotting tool for visualizing 3D scalar and vector fields in pythong using matplotlib or pyvista.

### Installation
ThreeDViewer can be installed through pip:

```pip install ThreeDViewer```

### Documentation
Comprehensive documentation is available in the doc directory or online at [readthedocs](https://ThreeDViewer.readthedocs.io/en/latest/index.html)
